@@ -1,10 +1,9 @@
-
 class CerebrateError(Exception):
     def __init__(
-            self,
-            message=None,
-            status=None,
-            code=None,
+        self,
+        message=None,
+        status=None,
+        code=None,
     ):
         super(CerebrateError, self).__init__(message)
 
@@ -15,8 +14,8 @@ class CerebrateError(Exception):
     def __str__(self):
         message = self._message or "<empty message>"
         code = self._code or 500
-        status = self._status or 'Server Error'
-        return f'{code} {status}: {message}'
+        status = self._status or "Server Error"
+        return f"{code} {status}: {message}"
 
     def __repr__(self):
         return "%s(code=%r, status=%r, message=%r)" % (
@@ -49,4 +48,3 @@ class ArgumentValidationError(CerebrateError):
 
 class AuthenticationError(CerebrateError):
     pass
-
